<?php
/**
 * The header for our theme.
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Jumla
 */

?><!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
    <meta charset="<?php bloginfo('charset'); ?>">
    <meta name="viewport" content="width=device-width, initial-scale=1.0, maximum-scale=1.0, user-scalable=no" />
    <link rel="profile" href="http://gmpg.org/xfn/11">
    <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">

    <?php wp_head(); ?>

</head>

<body <?php body_class(); ?>>
<?php if ( function_exists( 'wp_body_open' ) ) {
    wp_body_open();
}
?>
<?php if ((jumla_get_option('enable_preloader')) == 1) { ?>
    <div class="preloader">
        <div class="loader">
        <?php if ((jumla_get_option('enable_sitetitle_on_preloader')) == 1) { ?>
            <span class="loader-text loader-text-1" data-text="<?php bloginfo('name'); ?>"> <?php bloginfo('name'); ?></span>
        <?php }
        $jumla_pre_additional_text = jumla_get_option('preloader_additional_text');
        if ((!empty($jumla_pre_additional_text))) {?>
            <span class="loader-text loader-text-2" data-text="<?php echo esc_html(jumla_get_option('preloader_additional_text')); ?>"><?php echo esc_html(jumla_get_option('preloader_additional_text')); ?></span>
        <?php } ?>
        </div>
    </div>
<?php } ?>
<!-- full-screen-layout/boxed-layout -->
<?php if (jumla_get_option('homepage_layout_option') == 'full-width') {
    $jumla_homepage_layout = 'full-screen-layout';
} elseif (jumla_get_option('homepage_layout_option') == 'boxed') {
    $jumla_homepage_layout = 'boxed-layout';
} ?>
<?php if (jumla_get_option('disable_center_nav') == 1) {
    $jumla_homepage_menu_alignment = 'nav-none-center';
} else{
    $jumla_homepage_menu_alignment = 'nav-center';
} ?>
<div id="page" class="site site-bg <?php echo esc_attr($jumla_homepage_layout); ?>">
    <a class="skip-link screen-reader-text" href="#main"><?php esc_html_e('Skip to content', 'jumla'); ?></a>

    <header id="masthead" class="site-header <?php echo esc_attr($jumla_homepage_menu_alignment); ?>" role="banner">
        <div id="nav-affix" class="top-header header--fixed primary-bgcolor">
            <div class="container">
                <nav class="main-navigation" role="navigation">

                    <a class="skip-link-menu-start" href="javascript:void(0)"></a>

                    <a class="toggle-menu" href="javascript:void(0)" aria-controls="primary-menu" aria-expanded="false">
                         <span class="screen-reader-text">
                            <?php esc_html_e('Primary Menu', 'jumla'); ?>
                        </span>
                        <i class="ham"></i>
                    </a>

                    <?php wp_nav_menu(array(
                        'theme_location' => 'primary',
                        'menu_id' => 'primary-menu',
                        'container' => 'div',
                        'container_class' => 'menu'
                    )); ?>

                    <a class="skip-link-menu-end" href="javascript:void(0)"></a>
                    
                    <div class="nav-right">

                        <button class="icon-search">
                            <i class="ion-ios-search-strong"></i>
                        </button>

                        <div class="social-icons">
                            <?php
                            wp_nav_menu(
                                array('theme_location' => 'social',
                                    'link_before' => '<span>',
                                    'link_after' => '</span>',
                                    'menu_id' => 'social-menu',
                                    'fallback_cb' => false,
                                    'menu_class' => false
                                )); ?>
                        </div>

                    </div>

                </nav><!-- #site-navigation -->
            </div>
        </div>

        <div class="wrapper">
            <div class="col-row">
                <div class="col col-full">
                    <div class="site-branding">
                        <div class="twp-site-branding">
                            <div class="branding-center">
                                <?php
                                jumla_the_custom_logo();
                                if (is_front_page() && is_home()) : ?>
                                    <div class="site-title primary-font">
                                        <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
                                            <?php bloginfo('name'); ?>
                                        </a>
                                    </div>
                                <?php else : ?>
                                    <div class="site-title primary-font">
                                        <a href="<?php echo esc_url(home_url('/')); ?>" rel="home">
                                            <?php bloginfo('name'); ?>
                                        </a>
                                    </div>
                                <?php
                                endif;
                                $description = get_bloginfo('description', 'display');
                                if ($description || is_customize_preview()) : ?>
                                    <p class="site-description">
                                        <?php echo esc_html($description); ?>
                                    </p>
                                <?php
                                endif; ?>
                            </div>
                        </div>
                    </div>
                    <!-- .site-branding -->
                </div>
            </div>
        </div>

    </header>
    <!-- #masthead -->
    <div class="popup-search">
        <div class="table-align">
            <a class="skip-link-search" href="javascript:void(0)"></a>
            
            <div class="table-align-cell v-align-middle">
                <?php get_search_form(); ?>
            </div>
            <a href="javascript:void(0)" class="close-popup"></a>
            <a class="skip-link-search-end" href="javascript:void(0)"></a>
        </div>
        
    </div>
    <!--    Searchbar Ends-->
    <!-- Innerpage Header Begins Here -->
    <?php
    if (is_front_page() || is_home()) {
        do_action('jumla_action_slider_post');
        do_action('jumla_action_intro_post');
    } else {
        do_action('jumla-page-inner-title');
    }
    ?>
    <!-- Innerpage Header Ends Here -->
    <div id="content" class="site-content">