<?php
/**
 * CSS related hooks.
 *
 * This file contains hook functions which are related to CSS.
 *
 * @package Jumla
 */

if (!function_exists('jumla_trigger_custom_css_action')):

    /**
     * Do action theme custom CSS.
     *
     * @since 1.0.0
     */
    function jumla_trigger_custom_css_action()
    {
        global $jumla_google_fonts;
        $jumla_enable_banner_overlay = jumla_get_option('enable_overlay_option');
        $jumla_primary_color = jumla_get_option('primary_color');
        $jumla_secondary_color = jumla_get_option('secondary_color');
        $jumla_primary_font = $jumla_google_fonts[jumla_get_option('primary_font')];
        $jumla_secondary_font = $jumla_google_fonts[jumla_get_option('secondary_font')];

        $jumla_font_title_font_small = jumla_get_option('text_size_title_font_small');
        $jumla_font_title_font_big = jumla_get_option('text_size_title_font_big');
        $jumla_font_size_p = jumla_get_option('text_size_p');

        ?>
        <style type="text/css">
            <?php if ($jumla_enable_banner_overlay == 1) {
                ?>
            body .inner-header-overlay,
            body .single-slide-overlay {
                filter: alpha(opacity=62);
                opacity: .62;
            }

            body .ingle-slide-overlay {
                content: "";
            }

            <?php } ?>

            <?php if (!empty($jumla_primary_color) ){ ?>
            body .site button,
            body .site input[type="button"],
            body .site input[type="reset"],
            body .site input[type="submit"],
            body .site .btn-primary,
            body .site .scroll-up:hover,
            body .site .scroll-up:focus{
                background: <?php echo esc_html($jumla_primary_color); ?>;
            }

            body .site button,
            body .site input[type="button"],
            body .site input[type="reset"],
            body .site input[type="submit"],
            body .site .btn-primary,
            body .site .site-footer .author-info .profile-image {
                border-color: <?php echo esc_html($jumla_primary_color); ?>;
            }

            body .loader-text-2:before,
            body .site a:hover,
            body .site a:focus,
            body .site a:active,
            body .sticky header:before,
            body .entry-meta .post-category a{
                color: <?php echo esc_html($jumla_primary_color); ?>;
            }

            @media only screen and (min-width: 992px) {
                body .main-navigation .menu > ul > li:hover > a,
                body .main-navigation .menu > ul > li:focus > a,
                body .main-navigation .menu > ul > li.current-menu-item > a {
                    background: <?php echo esc_html($jumla_primary_color); ?>;
                }
            }

            <?php } ?>

            <?php if (!empty($jumla_secondary_color) ){ ?>
            body .primary-bgcolor,
            body button:hover,
            body button:focus,
            body input[type="button"]:hover,
            body input[type="button"]:focus,
            body input[type="reset"]:hover,
            body input[type="reset"]:focus,
            body input[type="submit"]:hover,
            body input[type="submit"]:focus,
            body .scroll-up {
                background: <?php echo esc_html($jumla_secondary_color); ?>;
            }

            body .primary-textcolor {
                color: <?php echo esc_html($jumla_secondary_color); ?>;;
            }

            body button:hover,
            body button:focus,
            body input[type="button"]:hover,
            body input[type="button"]:focus,
            body input[type="reset"]:hover,
            body input[type="reset"]:focus,
            body input[type="submit"]:hover,
            body input[type="submit"]:focus {
                border-color: <?php echo esc_html($jumla_secondary_color); ?>;
            }

            <?php } ?>

            <?php if (!empty($jumla_primary_font) ){ ?>
            body,
            body .site button,
            body .site input,
            body .site select,
            body .site textarea,
            body .site .primary-font,
            body .site .widget-title,
            body .site .section-title,
            body .site-info .site-copyright{
                font-family: <?php echo esc_html($jumla_primary_font); ?> !important;
            }

            <?php } ?>

            <?php if (!empty($jumla_secondary_font) ){ ?>
            body .site h1,
            body .site h2,
            body .site h3,
            body .site h4,
            body .site h5,
            body .site h6,
            body .site .secondary-font  {
                font-family: <?php echo esc_html($jumla_secondary_font); ?> !important;
            }

            <?php } ?>

            <?php if (!empty($jumla_font_title_font_small) ){ ?>
             body .featured-details .entry-title,
             body .site .entry-title-small{
                font-size: <?php echo esc_html($jumla_font_title_font_small); ?>px !important;
            }

            <?php } ?>

            <?php if (!empty($jumla_font_title_font_big) ){ ?>
            body .site .entry-title-big,
            body .site .slide-title{
                font-size: <?php echo esc_html($jumla_font_title_font_big); ?>px !important;
            }

            <?php } ?>

            <?php if (!empty($jumla_font_size_p) ){ ?>
            body,
            body .site button,
            body .site input,
            body .site select,
            body .site textarea,
            body .site p,
            body .site .main-navigation .toggle-menu{
                font-size: <?php echo esc_html($jumla_font_size_p); ?>px !important;
            }

            <?php } ?>

        </style>

    <?php }

endif;